@@ -125,6 +125,11 @@ import Distribution.Types.LibraryName
        (libraryNameString)
 #endif
 
+#if MIN_VERSION_Cabal(3,6,0)
+import Distribution.Utils.Path
+       (getSymbolicPath)
+#endif
+
 #if MIN_VERSION_directory(1,2,2)
 import System.Directory
        (makeAbsolute)
@@ -326,7 +331,11 @@ generateBuildModule testSuiteName flags pkg lbi = do
               <- mapM makeAbsolute
                $ compAutogenDir           -- autogenerated files
                : (distPref ++ "/build")   -- preprocessed files (.hsc -> .hs); "build" is hardcoded in Cabal.
+#if MIN_VERSION_Cabal(3,6,0)
+               : map getSymbolicPath (hsSourceDirs compBI)
+#else
                : hsSourceDirs compBI
+#endif
            includeArgs <- mapM (fmap ("-I"++) . makeAbsolute) $ includeDirs compBI
            -- We clear all includes, so the CWD isn't used.
            let iArgs' = map ("-i"++) iArgsNoPrefix
